@@ -676,7 +676,7 @@ class TrainLoop:
         if not DEEPSPEED_AVAILABLE:
             raise ValueError('Trying to use Microsoft DeepSpeed. However, DeepSpeed is not installed.')
         if self.use_amp:
-            raise ValueError('Base Nvidia APEX AMP enabled. To use DeepSpeed first disable base AMP and specfiy '
+            raise ValueError('Base Nvidia APEX AMP enabled. To use DeepSpeed first disable base AMP and specify '
                              'the AMP as part of DeepSpeed config.')
 
         self.use_deepspeed = True
@@ -695,6 +695,8 @@ class TrainLoop:
     def __call__(self, num_epochs, callbacks=None, grad_accumulation=1, **kwargs):
         """Train the model using the train loop
 
+        This is a convenience function which calls the main TrainLoop model training method fit().
+
         Args:
             num_epochs (int): how many epochs the network will be trained
             callbacks (list): callbacks that are executed during the training run
